MarcoPolo
=========

MarcoPolo is a service discovery protocol built over Twisted and UDP multicast messages. It allows the discovery of nodes and services in a network and works simultaneously in different multicast groups.